========
Examples
========

The `examples/ folder <https://github.com/chrisvoncsefalvay/sadie/tree/master/examples>`_ contains a growing number of examples that illustrate the capabilities of Sadie.

Basic Lévy walks
----------------

`The Basic Levy walks notebook <https://github.com/chrisvoncsefalvay/sadie/blob/master/examples/Basic%20Levy%20walks.ipynb>`_ illustrates the Lévy walks (bounded and unbounded Lévy walks) included with Sadie.

